PALM-meteo: palmmeteo.library.NCDates Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
palmmeteo.library.NCDates Class Reference

## Public Member Functions
| __init__ (self, ncvar)
| from_origin (cls, dt_origin, units, times)
| match_hselect (self, hselect)

## Public Attributes
| origin
| times
| matching

## Detailed Description

    Represents dates found in an NetCDF file with CF conventions and their
    match (intersection) with given HorizonSelection.

## Constructor & Destructor Documentation

## ◆ __init__()

palmmeteo.library.NCDates.__init__ | ( |  | self,
|  |  | ncvar
| ) |  |

## Member Function Documentation

## ◆ from_origin()

palmmeteo.library.NCDates.from_origin | ( |  | cls,
|  |  | dt_origin,
|  |  | units,
|  |  | times
| ) |  |

## ◆ match_hselect()

palmmeteo.library.NCDates.match_hselect | ( |  | self,
|  |  | hselect
| ) |  |

    Find file time indices (if any) that match the given HorizonSelection

## Member Data Documentation

## ◆ matching

palmmeteo.library.NCDates.matching

## ◆ origin

palmmeteo.library.NCDates.origin

## ◆ times

palmmeteo.library.NCDates.times

The documentation for this class was generated from the following file:

- palmmeteo/library.py